pcb_width = 140;
pcb_height = 76;
pcb_thick = 1.7;
pcb_hole_dia = 3.2;
pcb_pad_dia = 6.6;
pcb_corn_rad = 4.5;
pcb_hole_xdist = pcb_width - pcb_corn_rad * 2;
pcb_hole_ydist = pcb_height - pcb_corn_rad * 2;
pcb_usb_xoffs = 74.8;
pcb_usb_width = 8;
pcb_usb_height = 3;
bnsep = 20;
bnheight = 6;
bnwidth = 6;
bndia = 4;
fpwidth = bnsep * 2 + bnwidth * 2;
fpthick = 1.5;
fpbevel = 1;

thick = 2.5;
height = 10;
outer_bevel = pcb_corn_rad + thick/2;
inner_bevel = pcb_corn_rad - thick/2;

hex_nut_dia = 6.5;

tolerance = 0.3;

module pcb()
{
	linear_extrude(pcb_thick + tolerance) {
		union() {
			minkowski() {
				square([pcb_hole_xdist + tolerance * 2, pcb_hole_ydist + tolerance * 2], center=true);
				circle(r=pcb_corn_rad, $fn=25);
			}
			
			translate([0, -pcb_height/2, 0])
			square([fpwidth, 1.5], center=true);
		}
	}
	
	hull() {
		x = pcb_usb_xoffs - pcb_width/2;
		translate([x-pcb_usb_width/2, pcb_height/2 - 0.1, pcb_thick])
		rotate([-90, 0, 0])
		cylinder(thick + 0.1, r=pcb_usb_height/2, $fn=20);
		translate([x+pcb_usb_width/2, pcb_height/2, pcb_thick])
		rotate([-90, 0, 0])
		cylinder(thick + 0.1, r=pcb_usb_height/2, $fn=20);
	}
}

module base()
{
	difference() {
		translate([-pcb_hole_xdist/2, -pcb_hole_ydist/2, outer_bevel])
		minkowski() {
			cube([pcb_hole_xdist, pcb_hole_ydist, height]);
			sphere(r=outer_bevel, $fn=50);
		}
		
		translate([-pcb_width, -pcb_height, height+outer_bevel])
		cube([pcb_width * 2, pcb_height * 2, 100]);
		
		difference() {
			translate([-pcb_hole_xdist/2, -pcb_hole_ydist/2, inner_bevel + thick])
			minkowski() {
				cube([pcb_hole_xdist, pcb_hole_ydist, 50]);
				sphere(r=inner_bevel, $fn=30);
			}
			
			for(i=[0:3]) {
				x = (((i % 2) * 2) - 1) * pcb_hole_xdist / 2;
				y = (((floor(i / 2) % 2) * 2) - 1) * pcb_hole_ydist / 2;
				
				translate([x, y, -10])
				cylinder(100, d=pcb_pad_dia * 1.3, $fn=50);
			}
		}
		
		for(i=[0:3]) {
			x = (((i % 2) * 2) - 1) * pcb_hole_xdist / 2;
			y = (((floor(i / 2) % 2) * 2) - 1) * pcb_hole_ydist / 2;
			
			translate([x, y, -0.01]) {
				cylinder(100, d=pcb_hole_dia + tolerance * 2, $fn=20);
				
				/* hex nut hole */
				union() {
					top = height + outer_bevel - thick * 2 - pcb_thick;
					cylinder(top-1.98, d=hex_nut_dia + tolerance * 2, $fn=6);
					
					translate([0, 0, top - 2])
					cylinder(2, d1=hex_nut_dia + tolerance * 2, d2=pcb_hole_dia + tolerance * 2, $fn=6);
				}
			}
		}
		
		translate([0, 0, height + outer_bevel - pcb_thick + 0.01])
		pcb();
	}
}

module frontpanel()
{
	translate([0, -pcb_height/2 - thick/3 - fpthick/2, height + outer_bevel]) {
		difference() {
			intersection() {
				translate([0, 0, bnheight/3])
				cube([fpwidth*2, fpthick, bnheight*4], center=true);
			
				hull() {
					dia1 = bnheight * 1.5;
					dia2 = bnheight * 1.1;
					y = bnheight/2;
					translate([-bnsep, fpthick/2 + 0.01, y])
					rotate([90, 0, 0])
					cylinder(fpthick + 0.02, d1=dia1, d2=dia2, $fn=40);
					translate([bnsep, fpthick/2 + 0.01, y])
					rotate([90, 0, 0])
					cylinder(fpthick + 0.02, d1=dia1, d2=dia2, $fn=40);
					
					translate([-bnsep*1.05, fpthick/2 + 0.01, 0])
					rotate([90, 0, 0])
					cylinder(fpthick + 0.02, d1=dia1, d2=dia2, $fn=40);
					translate([bnsep*1.05, fpthick/2 + 0.01, 0])
					rotate([90, 0, 0])
					cylinder(fpthick + 0.02, d1=dia1, d2=dia2, $fn=40);
				}
			}
			
			for(i=[0:2]) {
				x = (i - 1) * bnsep;
				translate([x, thick, bnheight/2])
				rotate([90, 0, 0])
				cylinder(thick * 2, d=bndia+tolerance, $fn=18);
			}
		}
	}
}

module hvcap_clip()
{
	translate([-pcb_width/2-thick/2, -7, height+outer_bevel]) {
		difference() {
			hull() {
				cube([thick/3, 14, 3]);
				translate([0, -2, -1])
				cube([thick/3, 18, 1]);
			}
			
			translate([-0.1, 2, 0.2])
			cube([thick, 3, 1.5]);
			
			translate([-0.1, 9, 0.2])
			cube([thick, 3, 1.5]);
		}
	}
}

base();
frontpanel();
hvcap_clip();

/*
intersection() {
base();

translate([-pcb_hole_xdist/2, -pcb_hole_ydist/2, 6+outer_bevel])
cube([12, 12, 15], center=true);
}
*/